==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/lv.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Nevar nosūtīt epastu, sekojošiem lietotājiem: %s",
    "Turned on maintenance mode" : "Ieslēgts uzturēšanas režīms",
    "Turned off maintenance mode" : "Izslēgts uzturēšanas režīms",
    "Updated database" : "Atjaunota datu bāze",
    "Unknown filetype" : "Nezināms datnes tips",
    "Invalid image" : "Nederīgs attēls",
    "Sunday" : "Svētdiena",
    "Monday" : "Pirmdiena",
    "Tuesday" : "Otrdiena",
    "Wednesday" : "Trešdiena",
    "Thursday" : "Ceturtdiena",
    "Friday" : "Piektdiena",
    "Saturday" : "Sestdiena",
    "Sun." : "Sv.",
    "Mon." : "Pr.",
    "Tue." : "Ot.",
    "Wed." : "Tr.",
    "Thu." : "Ce.",
    "Fri." : "Pk.",
    "Sat." : "Se.",
    "January" : "Janvāris",
    "February" : "Februāris",
    "March" : "Marts",
    "April" : "Aprīlis",
    "May" : "Maijs",
    "June" : "Jūnijs",
    "July" : "Jūlijs",
    "August" : "Augusts",
    "September" : "Septembris",
    "October" : "Oktobris",
    "November" : "Novembris",
    "December" : "Decembris",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Jūn.",
    "Jul." : "Jūl.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "Settings" : "Iestatījumi",
    "Saving..." : "Saglabā...",
    "seconds ago" : "sekundes atpakaļ",
    "I know what I'm doing" : "Es zinu ko es daru",
    "Password can not be changed. Please contact your administrator." : "Paroli, nevar nomainīt. Lūdzu kontaktēties ar savu administratoru.",
    "No" : "Nē",
    "Yes" : "Jā",
    "Choose" : "Izvēlieties",
    "Ok" : "Labi",
    "read-only" : "tikai-skatīt",
    "New Files" : "Jaunās datnes",
    "Cancel" : "Atcelt",
    "(all selected)" : "(visus iezīmētos)",
    "Very weak password" : "Ļoti vāja parole",
    "Weak password" : "Vāja parole",
    "So-so password" : "Normāla parole",
    "Good password" : "Laba parole",
    "Strong password" : "Lieliska parole",
    "Shared" : "Kopīgs",
    "Error" : "Kļūda",
    "Error while sharing" : "Kļūda, daloties",
    "Error while unsharing" : "Kļūda, beidzot dalīties",
    "Error while changing permissions" : "Kļūda, mainot atļaujas",
    "Error setting expiration date" : "Kļūda, iestatot termiņa datumu",
    "Set expiration date" : "Iestaties termiņa datumu",
    "Expiration date" : "Termiņa datums",
    "Sending ..." : "Sūta...",
    "Email sent" : "Vēstule nosūtīta",
    "Resharing is not allowed" : "Atkārtota dalīšanās nav atļauta",
    "Password protect" : "Aizsargāt ar paroli",
    "Password" : "Parole",
    "Email link to person" : "Sūtīt saiti personai pa e-pastu",
    "Send" : "Sūtīt",
    "Shared with you and the group {group} by {owner}" : "{owner} dalījās ar jums un grupu {group}",
    "Shared with you by {owner}" : "{owner} dalījās ar jums",
    "Shared in {item} with {user}" : "Dalījās ar {item} ar {user}",
    "group" : "grupa",
    "Unshare" : "Pārtraukt dalīšanos",
    "can share" : "Var dalīties",
    "can edit" : "var rediģēt",
    "create" : "izveidot",
    "delete" : "dzēst",
    "access control" : "piekļuves vadība",
    "Share" : "Dalīties",
    "Warning" : "Brīdinājums",
    "The object type is not specified." : "Nav norādīts objekta tips.",
    "Delete" : "Dzēst",
    "Add" : "Pievienot",
    "The update was successful. Redirecting you to ownCloud now." : "Atjaunināšana beidzās sekmīgi. Tagad pārsūta jūs uz ownCloud.",
    "%s password reset" : "%s paroles maiņa",
    "Use the following link to reset your password: {link}" : "Izmantojiet šo saiti, lai mainītu paroli: {link}",
    "New password" : "Jauna parole",
    "Reset password" : "Mainīt paroli",
    "Personal" : "Personīgi",
    "Users" : "Lietotāji",
    "Apps" : "Lietotnes",
    "Admin" : "Administratori",
    "Help" : "Palīdzība",
    "Access forbidden" : "Pieeja ir liegta",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Visticamāk, jūsu datu direktorija un datnes ir pieejamas no interneta, jo .htaccess datne nedarbojas.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Vairāk informācijai kā konfigurēt serveri, lūdzu skatiet <a href=\"%s\" target=\"_blank\">dokumentāciju</a>.",
    "Create an <strong>admin account</strong>" : "Izveidot <strong>administratora kontu</strong>",
    "Username" : "Lietotājvārds",
    "Data folder" : "Datu mape",
    "Configure the database" : "Konfigurēt datubāzi",
    "Database user" : "Datubāzes lietotājs",
    "Database password" : "Datubāzes parole",
    "Database name" : "Datubāzes nosaukums",
    "Database tablespace" : "Datubāzes tabulas telpa",
    "Database host" : "Datubāzes serveris",
    "Finish setup" : "Pabeigt iestatīšanu",
    "Log out" : "Izrakstīties",
    "Search" : "Meklēt",
    "Log in" : "Ierakstīties",
    "remember" : "atcerēties",
    "Alternative Logins" : "Alternatīvās pieteikšanās"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/core/l10n/lv.js <==
OC.L10N.register(
    "core",
    {
    "Couldn't send mail to following users: %s " : "Nevar nosūtīt epastu, sekojošiem lietotājiem: %s",
    "Turned on maintenance mode" : "Ieslēgts uzturēšanas režīms",
    "Turned off maintenance mode" : "Izslēgts uzturēšanas režīms",
    "Updated database" : "Atjaunota datu bāze",
    "Unknown filetype" : "Nezināms datnes tips",
    "Invalid image" : "Nederīgs attēls",
    "%s password reset" : "%s paroles maiņa",
    "Sunday" : "Svētdiena",
    "Monday" : "Pirmdiena",
    "Tuesday" : "Otrdiena",
    "Wednesday" : "Trešdiena",
    "Thursday" : "Ceturtdiena",
    "Friday" : "Piektdiena",
    "Saturday" : "Sestdiena",
    "Sun." : "Sv.",
    "Mon." : "Pr.",
    "Tue." : "Ot.",
    "Wed." : "Tr.",
    "Thu." : "Ce.",
    "Fri." : "Pk.",
    "Sat." : "Se.",
    "January" : "Janvāris",
    "February" : "Februāris",
    "March" : "Marts",
    "April" : "Aprīlis",
    "May" : "Maijs",
    "June" : "Jūnijs",
    "July" : "Jūlijs",
    "August" : "Augusts",
    "September" : "Septembris",
    "October" : "Oktobris",
    "November" : "Novembris",
    "December" : "Decembris",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "Mai.",
    "Jun." : "Jūn.",
    "Jul." : "Jūl.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "Settings" : "Iestatījumi",
    "Saving..." : "Saglabā...",
    "seconds ago" : "sekundes atpakaļ",
    "I know what I'm doing" : "Es zinu ko es daru",
    "Password can not be changed. Please contact your administrator." : "Paroli, nevar nomainīt. Lūdzu kontaktēties ar savu administratoru.",
    "No" : "Nē",
    "Yes" : "Jā",
    "Choose" : "Izvēlieties",
    "Ok" : "Labi",
    "read-only" : "tikai-skatīt",
    "New Files" : "Jaunās datnes",
    "Cancel" : "Atcelt",
    "(all selected)" : "(visus iezīmētos)",
    "Very weak password" : "Ļoti vāja parole",
    "Weak password" : "Vāja parole",
    "So-so password" : "Normāla parole",
    "Good password" : "Laba parole",
    "Strong password" : "Lieliska parole",
    "Shared" : "Kopīgs",
    "Error" : "Kļūda",
    "Error while sharing" : "Kļūda, daloties",
    "Error while unsharing" : "Kļūda, beidzot dalīties",
    "Error setting expiration date" : "Kļūda, iestatot termiņa datumu",
    "Set expiration date" : "Iestaties termiņa datumu",
    "Expiration date" : "Termiņa datums",
    "Sending ..." : "Sūta...",
    "Email sent" : "Vēstule nosūtīta",
    "Resharing is not allowed" : "Atkārtota dalīšanās nav atļauta",
    "Share link" : "Dalīt saiti",
    "Password protect" : "Aizsargāt ar paroli",
    "Password" : "Parole",
    "Email link to person" : "Sūtīt saiti personai pa e-pastu",
    "Send" : "Sūtīt",
    "Shared with you and the group {group} by {owner}" : "{owner} dalījās ar jums un grupu {group}",
    "Shared with you by {owner}" : "{owner} dalījās ar jums",
    "group" : "grupa",
    "Unshare" : "Pārtraukt dalīšanos",
    "can share" : "Var dalīties",
    "can edit" : "var rediģēt",
    "create" : "izveidot",
    "delete" : "dzēst",
    "access control" : "piekļuves vadība",
    "Share" : "Dalīties",
    "Warning" : "Brīdinājums",
    "Delete" : "Dzēst",
    "Rename" : "Pārsaukt",
    "The object type is not specified." : "Nav norādīts objekta tips.",
    "Add" : "Pievienot",
    "The update was successful. Redirecting you to ownCloud now." : "Atjaunināšana beidzās sekmīgi. Tagad pārsūta jūs uz ownCloud.",
    "Personal" : "Personīgi",
    "Users" : "Lietotāji",
    "Apps" : "Lietotnes",
    "Admin" : "Administratori",
    "Help" : "Palīdzība",
    "Access forbidden" : "Pieeja ir liegta",
    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Visticamāk, jūsu datu direktorija un datnes ir pieejamas no interneta, jo .htaccess datne nedarbojas.",
    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Vairāk informācijai kā konfigurēt serveri, lūdzu skatiet <a href=\"%s\" target=\"_blank\">dokumentāciju</a>.",
    "Create an <strong>admin account</strong>" : "Izveidot <strong>administratora kontu</strong>",
    "Username" : "Lietotājvārds",
    "Data folder" : "Datu mape",
    "Configure the database" : "Konfigurēt datubāzi",
    "Database user" : "Datubāzes lietotājs",
    "Database password" : "Datubāzes parole",
    "Database name" : "Datubāzes nosaukums",
    "Database tablespace" : "Datubāzes tabulas telpa",
    "Database host" : "Datubāzes serveris",
    "Finish setup" : "Pabeigt iestatīšanu",
    "Log out" : "Izrakstīties",
    "Search" : "Meklēt",
    "Log in" : "Ierakstīties",
    "Alternative Logins" : "Alternatīvās pieteikšanās",
    "Use the following link to reset your password: {link}" : "Izmantojiet šo saiti, lai mainītu paroli: {link}",
    "New password" : "Jauna parole",
    "Reset password" : "Mainīt paroli"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
